==> haskell-generic-random-1.4.0.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-random
version:              1.4.0.0
visibility:           public
id:                   generic-random-1.4.0.0-8kTCaukz7B1ERqBTRpgSFJ
key:                  generic-random-1.4.0.0-8kTCaukz7B1ERqBTRpgSFJ
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  52ac592ee985664044dde7d624aa7a0f
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.Internal.BaseCase
    Generic.Random.Internal.Generic Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-8.10.5/site-local/generic-random-1.4.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/generic-random-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/generic-random-1.4.0.0
hs-libraries:         HSgeneric-random-1.4.0.0-8kTCaukz7B1ERqBTRpgSFJ
depends:
    QuickCheck-2.14.2-EY3HyfbcTB28zfII1FrkZg base-4.14.2.0

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-random-1.4.0.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-random
version:              1.4.0.0
visibility:           public
id:                   generic-random-1.4.0.0-JiKa4JAtR1V5EcXmMqx1DQ
key:                  generic-random-1.4.0.0-JiKa4JAtR1V5EcXmMqx1DQ
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  bb542f2dc31e6208b09ef00897cc9de0
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.Internal.BaseCase
    Generic.Random.Internal.Generic Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.0.1/site-local/generic-random-1.4.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/generic-random-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/generic-random-1.4.0.0
hs-libraries:         HSgeneric-random-1.4.0.0-JiKa4JAtR1V5EcXmMqx1DQ
depends:
    QuickCheck-2.14.2-5cPRTtrxXz46wA1XUCyvzI base-4.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
